@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.109';
+$Config::Model::VERSION = '2.110';
 use strict ;
 use warnings;
 use 5.10.1;
@@ -702,15 +702,17 @@ sub translate_legacy_backend_info {
 
     if ($model->{read_config}) {
         $self->show_legacy_issue("$config_class_name: read_config specification is deprecated, please move in rw_config", 'note');
-        $model->{rw_config} = delete $model->{read_config} unless $multi_backend;
+        # TODO: enable once COnfig::Model::Itself is ready
+        # $model->{rw_config} = delete $model->{read_config} unless $multi_backend;
     }
 
     if ($model->{write_config}) {
         $self->show_legacy_issue("$config_class_name: write_config specification is deprecated, please merge with read_config and move in rw_config", 'note');
-        if (not $multi_backend) {
-            map {$model->{rw_config}{$_} = $model->{write_config}{$_} } keys %{$model->{write_config}} ;
-            delete $model->{write_config};
-        }
+        # TODO: enable once Config::Model::Itself is ready
+        #if (not $multi_backend) {
+        #    map {$model->{rw_config}{$_} = $model->{write_config}{$_} } keys %{$model->{write_config}} ;
+        #    delete $model->{write_config};
+        #}
     }
 }
 
@@ -1811,7 +1813,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.109
+version 2.110
 
 =head1 SYNOPSIS
 
