@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::BackendMgr;
-$Config::Model::BackendMgr::VERSION = '2.109';
+$Config::Model::BackendMgr::VERSION = '2.110';
 use Mouse;
 use strict;
 use warnings;
@@ -270,7 +270,7 @@ sub read_config_data {
 
     my @list;
     if (ref  $readlist eq 'ARRAY') {
-        warn "Multiple backends are deprecated (read_config)" if @$readlist > 1;
+        say "Multiple backends are deprecated (read_config)" if @$readlist > 1;
         @list = @$readlist ;
     }
     elsif (ref  $readlist eq 'HASH') {
@@ -487,7 +487,7 @@ sub auto_write_init {
 
     my @array;
     if (ref  $wrlist eq 'ARRAY') {
-        warn "Multiple backends are deprecated (write_config)" if @$wrlist > 1;
+        say "Multiple backends are deprecated (write_config)\n" if @$wrlist > 1;
         @array = @$wrlist ;
     }
     elsif (ref  $wrlist eq 'HASH') {
@@ -716,7 +716,7 @@ Config::Model::BackendMgr - Load configuration node on demand
 
 =head1 VERSION
 
-version 2.109
+version 2.110
 
 =head1 SYNOPSIS
 
